@@ -252,8 +252,10 @@ sub key_tab_complete
 
       $popup->pen->chattrs({ bg => 'green', fg => 'black' });
 
-      $popup->set_on_expose( with_rb => sub {
-         my ( $win, $rb, $rect ) = @_;
+      $popup->bind_event( expose => sub {
+         my ( $win, undef, $info ) = @_;
+         my $rb = $info->rb;
+
          foreach my $line ( 0 .. $#possibles ) {
             my $str = $possibles[$line];
 
@@ -284,8 +286,10 @@ sub send_pending
       my $win = $self->{pending_window} ||= do {
          my $win = $self->window->make_hidden_sub( 0, $self->window->cols - 12, 1, 12 );
          my $countr = \$self->{pending_count};
-         $win->set_on_expose( with_rb => sub {
-            my ( undef, $rb, $rect ) = @_;
+         $win->bind_event( expose => sub {
+            my ( $win, undef, $info ) = @_;
+            my $rb = $info->rb;
+
             $rb->goto( 0, 0 );
             $rb->text( "Sending $$countr..." );
             $rb->erase_to( 12 );
